[multimedia/audiocd-kio] /: Port to KIO::WorkerBase

2022-07-05 Thread Friedrich W . H . Kossebau
Git commit 4edb67edad4f9efdef29ff690eed41003674adbf by Friedrich W. H. Kossebau.
Committed on 03/07/2022 at 16:06.
Pushed by kossebau into branch 'master'.

Port to KIO::WorkerBase

M  +4-4CMakeLists.txt
M  +2-2HACKING
M  +115  -153  audiocd.cpp
M  +13   -12   audiocd.h
M  +1-1data/org.kde.kio_audiocd.metainfo.xml
M  +4-4doc/index.docbook
M  +1-1kcmaudiocd/audiocd.desktop
M  +1-1kcmaudiocd/audiocdconfig.ui
M  +5-5kcmaudiocd/doc/index.docbook
M  +3-3kcmaudiocd/kcmaudiocd.cpp
M  +5-5plugins/audiocdencoder.cpp
M  +11   -11   plugins/audiocdencoder.h
M  +9-7plugins/flac/encoderflac.cpp
M  +6-6plugins/flac/encoderflac.h
M  +6-6plugins/lame/encoderlame.cpp
M  +1-1plugins/lame/encoderlame.h
M  +6-6plugins/opus/encoderopus.cpp
M  +1-1plugins/opus/encoderopus.h
M  +10   -8plugins/vorbis/encodervorbis.cpp
M  +6-6plugins/vorbis/encodervorbis.h
M  +1-1plugins/wav/encodercda.cpp
M  +4-1plugins/wav/encodercda.h
M  +4-4plugins/wav/encoderwav.cpp
M  +4-1plugins/wav/encoderwav.h

https://invent.kde.org/multimedia/audiocd-kio/commit/4edb67edad4f9efdef29ff690eed41003674adbf

diff --git a/CMakeLists.txt b/CMakeLists.txt
index b4ce7ce..d73972b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -3,7 +3,7 @@ cmake_minimum_required(VERSION 3.16)
 project(audiocd VERSION "5.0.0")
 
 set(QT_MIN_VERSION "5.15.0")
-set(KF_MIN_VERSION "5.90.0")
+set(KF_MIN_VERSION "5.96.0")
 
 find_package(ECM ${KF_MIN_VERSION} REQUIRED NO_MODULE)
 set(CMAKE_MODULE_PATH ${ECM_MODULE_PATH} "${CMAKE_CURRENT_SOURCE_DIR}/cmake")
@@ -100,10 +100,10 @@ target_sources(kio_audiocd PRIVATE
 ecm_qt_declare_logging_category(kio_audiocd
 HEADER audiocd_kio_debug.h
 IDENTIFIER AUDIOCD_KIO_LOG
-CATEGORY_NAME kf.kio.slaves.audiocd
-OLD_CATEGORY_NAMES kf5.kio.audiocd
+CATEGORY_NAME kf.kio.workers.audiocd
+OLD_CATEGORY_NAMES kf5.kio.audiocd kf.kio.slaves.audiocd
 DEFAULT_SEVERITY Warning
-DESCRIPTION "audiocd KIO slave"
+DESCRIPTION "audiocd KIO worker"
 EXPORT AUDIOCD
 )
 
diff --git a/HACKING b/HACKING
index 99725cc..14f40f1 100644
--- a/HACKING
+++ b/HACKING
@@ -1,6 +1,6 @@
 // CODE LAYOUT
 
-audiocd.[h,cpp] - The main ioslave code.  It contains the logic to rip audio 
from cd's.  It loads all of the plugins that it can find.  When it needs to 
encode, generate directories (and names of directories) it goes through it's 
list. audiocd uses libkcddb to retrieve its cddb entries and cdparinoia to 
retrieve the audio from the CD.
+audiocd.[h,cpp] - The main KIO worker code.  It contains the logic to rip 
audio from cd's.  It loads all of the plugins that it can find.  When it needs 
to encode, generate directories (and names of directories) it goes through it's 
list. audiocd uses libkcddb to retrieve its cddb entries and cdparinoia to 
retrieve the audio from the CD.
 
 plugins/audiocdencoder.[h,cpp] - The base class for all of the encoder plugins
 
@@ -10,7 +10,7 @@ plugins/opus/* - The opus encoder
 plugins/vorbis/* - The ogg encoder
 plugins/wav/* - The cda and wav "encoders"
 
-kcmaudiocd/ - kcm configure dialog for the audiocd ioslave.  It also loads the 
plugins and gets their configure dialogs and puts them into the tab dialog.
+kcmaudiocd/ - kcm configure dialog for the audiocd KIO worker.  It also loads 
the plugins and gets their configure dialogs and puts them into the tab dialog.
 
 // USERS
 
diff --git a/audiocd.cpp b/audiocd.cpp
index c15bb6a..b4d1aa7 100644
--- a/audiocd.cpp
+++ b/audiocd.cpp
@@ -59,7 +59,6 @@ int Q_DECL_EXPORT kdemain(int argc, char **argv);
 #include 
 #include 
 #include 
-#include 
 
 // CDDB
 #include 
@@ -69,7 +68,7 @@ int Q_DECL_EXPORT kdemain(int argc, char **argv);
 class KIOPluginForMetaData : public QObject
 {
 Q_OBJECT
-Q_PLUGIN_METADATA(IID "org.kde.kio.slave.audiocd" FILE "audiocd.json")
+Q_PLUGIN_METADATA(IID "org.kde.kio.worker.audiocd" FILE "audiocd.json")
 };
 
 using namespace KIO;
@@ -93,8 +92,8 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 
 qCDebug(AUDIOCD_KIO_LOG) << "Starting " << getpid();
 
-AudioCDProtocol slave(argv[1], argv[2], argv[3]);
-slave.dispatchLoop();
+AudioCDProtocol worker(argv[1], argv[2], argv[3]);
+worker.dispatchLoop();
 
 qCDebug(AUDIOCD_KIO_LOG) << "Done";
 
@@ -104,7 +103,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 enum Which_dir {
 Unknown = 0, // Error
 Info, // CDDB info
-Base, // The ioslave base directory showing all drives
+Base, // The KIO worker base directory showing all drives
 Root, // The root directory, shows all these :)
 FullCD, // Show a single file containing all of the data
 EncoderDir, // The root directory created by an encoder
@@ -193,7 +192,7 @@ public:
 int paranoia_read_limited_error;
 
 AudioCDProtocol::AudioCDProtocol(const QByteArray , const QByteArray 
, 

[Books] [Bug 456375] New: Invalid link to download the book

2022-07-05 Thread bugzilla_noreply
https://bugs.kde.org/show_bug.cgi?id=456375

Bug ID: 456375
   Summary: Invalid link to download the book
   Product: Books
   Version: unspecified
  Platform: Neon Packages
OS: Linux
Status: REPORTED
  Severity: major
  Priority: NOR
 Component: Frameworks Cookbook
  Assignee: kde-doc-english@kde.org
  Reporter: robloka...@gmail.com
  Target Milestone: ---

SUMMARY
The link on the Community wiki to download the book is to share.kde.org, but
the new address is collaborate.kde.org, so the download link doesn't work
anymore.

STEPS TO REPRODUCE
1. Try to download the book using the link on the Community wiki

OBSERVED RESULT
The book doesn't download because of the invalid link

EXPECTED RESULT
The book downloads

-- 
You are receiving this mail because:
You are the assignee for the bug.